@@ -4,15 +4,15 @@
 #'
 #' @param classAlloc_settings List of inputs of the MNL model. It should contain the following.
 #'                     \itemize{
-#'                       \item \strong{\code{V}}: Named list of deterministic utilities . Utilities of the alternatives. Names of elements must match those in \code{avail}, if provided.
-#'                       \item \strong{\code{avail}}: Named list of numeric vectors or scalars. Availabilities of alternatives, one element per alternative. Names of elements must match those in \code{V}. Values can be 0 or 1.
+#'                       \item \strong{\code{V}}: Named list of deterministic utilities . Utilities of the classes in class allocation model. Names of elements must match those in \code{avail}, if provided.
+#'                       \item \strong{\code{avail}}: Named list of numeric vectors or scalars. Availabilities of classes in class allocation model, one element per class Names of elements must match those in \code{V}. Values can be 0 or 1.
 #'                       \item \strong{\code{rows}}: Boolean vector. Consideration of rows in the likelihood calculation, FALSE to exclude. Length equal to the number of observations (nObs). Default is \code{"all"}, equivalent to \code{rep(TRUE, nObs)}.
 #'                       \item \strong{\code{componentName}}: Character. Name given to model component.
 #'                     }
 #' @return The returned object depends on the value of argument \code{functionality}, which it fetches from the calling stack.
 #'         \itemize{
 #'         "estimate","conditionals", "components", "output", "prediction", "raw", "report"
-#'           \item \strong{\code{"estimate"}}: vector/matrix/array. Returns the probabilities for all alternatives.
+#'           \item \strong{\code{"estimate"}}: vector/matrix/array. Returns the probabilities for all classes
 #'           \item \strong{\code{"prediction"}}: Same as \code{"estimate"}.
 #'           \item \strong{\code{"validate"}}: Same as \code{"estimate"}, but it also runs a set of tests to validate the function inputs.
 #'           \item \strong{\code{"zero_LL"}}: Returns a scalar NA.
@@ -128,8 +128,9 @@ apollo_classAlloc <- function(classAlloc_settings){
   # ############################## #
   
   if(functionality=="validate"){
-    if(!apollo_inputs$apollo_control$noValidation) apollo_validate(classAlloc_settings, modelType, 
-                                                                   functionality, apollo_inputs)
+    
+    if(!apollo_inputs$apollo_control$noValidation)apollo_validate(classAlloc_settings, modelType, 
+                                                                  functionality, apollo_inputs)
     
     # No diagnose for the class allocation component
     #if(!apollo_inputs$apollo_control$noDiagnostics) apollo_diagnostics(classAlloc_settings, modelType, apollo_inputs)
@@ -140,11 +141,17 @@ apollo_classAlloc <- function(classAlloc_settings){
     return(invisible(testL))
   }
   
-  # ############################## #
-  #### functionality="zero_LL" ####
-  # ############################## #
+  # ############################################ #
+  #### functionality="zero_LL" or "shares_LL" ####
+  # ############################################ #
   
-  if(functionality=="zero_LL") return(NA)
+  if(functionality %in% c("zero_LL", 'shares_LL')){
+    # turn scalar availabilities into vectors
+    for(i in 1:length(classAlloc_settings$avail)) if(length(classAlloc_settings$avail[[i]])==1) classAlloc_settings$avail[[i]] <- rep(classAlloc_settings$avail[[i]], classAlloc_settings$nObs) 
+    P <- lapply(classAlloc_settings$avail, '/', Reduce('+', classAlloc_settings$avail))
+    if(any(!classAlloc_settings$rows)) P <- lapply(P, apollo_insertRows, r=classAlloc_settings$rows, val=1)
+    return(P)
+  }
   
   # ################################################################################### #
   #### functionality="estimate/conditionals/components/output/prediction/raw/report" ####
