@@ -26,6 +26,7 @@
 #'                        \item \code{"prediction"} Used for model predictions.
 #'                        \item \code{"validate"} Used for validating input.
 #'                        \item \code{"zero_LL"} Used for calculating null likelihood.
+#'                        \item \code{"shares_LL"}: Used for calculating likelihood with constants only.
 #'                        \item \code{"conditionals"} Used for calculating conditionals.
 #'                        \item \code{"output"} Used for preparing output after model estimation.
 #'                        \item \code{"raw"} Used for debugging.
@@ -36,6 +37,7 @@
 #'           \item \strong{\code{"prediction"}}: A matrix with one row per observation, and columns indicating means and s.d. of continuous and discrete predicted consumptions.
 #'           \item \strong{\code{"validate"}}: Same as \code{"estimate"}, but it also runs a set of tests to validate the function inputs.
 #'           \item \strong{\code{"zero_LL"}}: Not implemented. Returns a vector of NA with as many elements as observations.
+#'           \item \strong{\code{"shares_LL"}}: Not implemented. Returns a vector of NA with as many elements as observations.
 #'           \item \strong{\code{"conditionals"}}: Same as \code{"estimate"}
 #'           \item \strong{\code{"output"}}: Same as \code{"estimate"} but also writes summary of input data to internal Apollo log.
 #'           \item \strong{\code{"raw"}}: Same as \code{"estimate"}
@@ -62,6 +64,9 @@ apollo_mdcev <- function(mdcev_settings,functionality){
     assign("apollo_modelList", apollo_modelList, envir=parent.frame())
   }
   
+  #### replace utilities by V if used
+  if(!is.null(mdcev_settings[["utilities"]])) names(mdcev_settings)[which(names(mdcev_settings)=="utilities")]="V"
+  
   # ############################### #
   #### Load or do pre-processing ####
   # ############################### #
@@ -279,11 +284,11 @@ apollo_mdcev <- function(mdcev_settings,functionality){
     return(invisible(testL))
   }
   
-  # ############################## #
-  #### functionality="zero_LL" ####
-  # ############################## #
+  # ####################################### #
+  #### functionality="zero_LL/shares_LL" ####
+  # ####################################### #
   
-  if(functionality=="zero_LL"){
+  if(functionality %in% c("zero_LL","shares_LL")){
     P <- rep(NA, mdcev_settings$nObs)
     if(any(!mdcev_settings$rows)) P <- apollo_insertRows(P, mdcev_settings$rows, 1)
     return(P)
