@@ -25,6 +25,7 @@
 #'                        \item "prediction" Used for model predictions.
 #'                        \item "validate" Used for validating input.
 #'                        \item "zero_LL" Used for calculating null likelihood.
+#'                        \item "shares_LL" Used for calculating likelihood with constants only.
 #'                        \item "conditionals" Used for calculating conditionals.
 #'                        \item "output" Used for preparing output after model estimation.
 #'                        \item "raw" Used for debugging.
@@ -35,6 +36,7 @@
 #'           \item \strong{\code{"prediction"}}: A matrix with one row per observation, and columns indicating means and s.d. of continuous and discrete predicted consumptions.
 #'           \item \strong{\code{"validate"}}: Same as \code{"estimate"}, but it also runs a set of tests to validate the function inputs.
 #'           \item \strong{\code{"zero_LL"}}: Not implemented. Returns a vector of NA with as many elements as observations.
+#'           \item \strong{\code{"shares_LL"}}: Not implemented. Returns a vector of NA with as many elements as observations.
 #'           \item \strong{\code{"conditionals"}}: Same as \code{"estimate"}
 #'           \item \strong{\code{"output"}}: Same as \code{"estimate"} but also writes summary of input data to internal Apollo log.
 #'           \item \strong{\code{"raw"}}: Same as \code{"estimate"}
@@ -63,6 +65,9 @@ apollo_mdcnev <- function(mdcnev_settings,functionality){
     assign("apollo_modelList", apollo_modelList, envir=parent.frame())
   }
   
+  #### replace utilities by V if used
+  if(!is.null(mdcnev_settings[["utilities"]])) names(mdcnev_settings)[which(names(mdcnev_settings)=="utilities")]="V"
+  
   # ############################### #
   #### Load or do pre-processing ####
   # ############################### #
@@ -300,16 +305,16 @@ apollo_mdcnev <- function(mdcnev_settings,functionality){
     return(invisible(testL))
   }
   
-  # ############################## #
-  #### functionality="zero_LL" ####
-  # ############################## #
-
-  if(functionality=="zero_LL"){
+  # ####################################### #
+  #### functionality="zero_LL/shares_LL" ####
+  # ####################################### #
+  
+  if(functionality %in% c("zero_LL","shares_LL")){
     P <- rep(NA, mdcnev_settings$nObs)
-    P[!mdcnev_settings$rows] <- 1
+    if(any(!mdcnev_settings$rows)) P <- apollo_insertRows(P, mdcnev_settings$rows, 1)
     return(P)
   }
-
+  
   # ################################################## #
   #### functionality="estimate/conditionals/output" ####
   # ################################################## #
