@@ -26,6 +26,7 @@
 #'                        \item \strong{"prediction"} Used for model predictions.
 #'                        \item \strong{"validate"} Used for validating input.
 #'                        \item \strong{"zero_LL"} Used for calculating null likelihood.n Not implemented for ordered probit.
+#'                        \item \code{"shares_LL"}: Used for calculating likelihood with constants only.
 #'                        \item \strong{"conditionals"} Used for calculating conditionals.
 #'                        \item \strong{"output"} Used for preparing output after model estimation.
 #'                        \item \strong{"raw"} Used for debugging.
@@ -36,6 +37,7 @@
 #'           \item \strong{\code{"prediction"}}: List of vectors/matrices/arrays. Returns a list with the probabilities for all possible levels, with an extra element for the probability of the chosen alternative.
 #'           \item \strong{\code{"validate"}}: Same as \code{"estimate"}, but it also runs a set of tests to validate the function inputs.
 #'           \item \strong{\code{"zero_LL"}}: Not implemented. Returns a vector of NA with as many elements as observations.
+#'           \item \strong{\code{"shares_LL"}}: Not implemented. Returns a vector of NA with as many elements as observations.
 #'           \item \strong{\code{"conditionals"}}: Same as \code{"estimate"}
 #'           \item \strong{\code{"output"}}: Same as \code{"estimate"} but also writes summary of input data to internal Apollo log.
 #'           \item \strong{\code{"raw"}}: Same as \code{"prediction"}
@@ -63,6 +65,9 @@ apollo_op  <- function(op_settings, functionality){
     assign("apollo_modelList", apollo_modelList, envir=parent.frame())
   }
   
+  #### replace utility by V if used
+  if(!is.null(op_settings[["utility"]])) names(op_settings)[which(names(op_settings)=="utility")]="V"
+  
   # ############################### #
   #### Load or do pre-processing ####
   # ############################### #
@@ -185,6 +190,16 @@ apollo_op  <- function(op_settings, functionality){
     return(P)
   }
 
+  # ############################### #
+  #### functionality="shares_LL" ####
+  # ############################### #
+  
+  if(functionality %in% c("shares_LL")){
+    P <- rep(NA, op_settings$nObs)
+    if(any(!op_settings$rows)) P <- apollo_insertRows(P, op_settings$rows, 1)
+    return(P)
+  }
+  
   # ############################################################# #
   #### functionality = estimate, conditional, raw & prediction ####
   # ############################################################# #
