@@ -11,19 +11,20 @@
 #' @param database data.frame. Data used by model.
 #' @param apollo_control List. Options controlling the running of the code.
 #'                       \itemize{
-#'                         \item \code{modelName}: Character. Name of the model. Used when saving the output to files. Avoid characters not allowed in file names, such as \code{\\}, \code{*}, \code{:}, etc.
+#'                         \item \code{modelName}: Character. Name of the model. Used when saving the output to files.
 #'                         \item \code{modelDescr}: Character. Description of the model. Used in output files.
 #'                         \item \code{indivID}: Character. Name of column in the database with each decision maker's ID.
 #'                         \item \code{mixing}: Boolean. TRUE for models that include random parameters.
-#'                         \item \code{nCores}: Numeric>0. Number of threads (processors) to use in estimation of the model.
-#'                         \item \code{workInLogs}: Boolean. TRUE for higher numeric stability at the expense of computational time.
-#'                                                  Useful for panel models only. Default is FALSE.
+#'                         \item \code{nCores}: Numeric>0. Number of cores to use in calculations of the model likelihood.
 #'                         \item \code{seed}: Numeric. Seed for random number generation.
 #'                         \item \code{HB}: Boolean. TRUE if using RSGHB for Bayesian estimation of model.
 #'                         \item \code{noValidation}: Boolean. TRUE if user does not wish model input to be validated before estimation - FALSE by default.
 #'                         \item \code{noDiagnostics}: Boolean. TRUE if user does not wish model diagnostics to be printed - FALSE by default.
-#'                         \item \code{panelData}: Boolean. TRUE if using panelData data (created automatically by \code{apollo_validateControl}).
+#'                         \item \code{outputDirectory}: Character. Optional directory for outputs if different from working director - empty by default
 #'                         \item \code{weights}: Character. Name of column in database containing weights for estimation.
+#'                         \item \code{workInLogs}: Boolean. TRUE for increased numeric precision in models with panel data - FALSE by default.
+#'                         \item \code{panelData}: Boolean. TRUE if there are multiple obsrvations (i.e. rows) for each decision maker - Automatically set based on \code{indivID} by default.
+#'                         \item \code{calculateLLC}: Boolean. TRUE if user wants to calculate LL at constants (if applicable). - TRUE by default.
 #'                       }
 #' @param apollo_HB List. Contains options for bayesian estimation. See \code{?RSGHB::doHB} for details.
 #'                   Parameters \code{modelname}, \code{gVarNamesFixed}, \code{gVarNamesNormal},
@@ -183,9 +184,10 @@ apollo_validateInputs <- function(apollo_beta=NA, apollo_fixed=NA, database=NA,
     if(length(toCopy)>0) for(i in toCopy) apollo_inputs[[i]] <- old_inputs[[i]]
   }
   
-  ### Check for repeated names across apollo_beta, database, apollo_draws, apollo_randCoeff, apollo_lcPars
+  ### Check for repeated names across apollo_beta, database, apollo_draws, apollo_randCoeff, apollo_lcPars, and globalEnv
   namesList <- list(apollo_beta = names(apollo_beta), # store apollo_beta names
-                    database    = names(database))    # store database names
+                    database    = names(database),    # store database names
+                    globalEnv   = ls(.GlobalEnv))     # store globalEnvironment names
   if(apollo_control$mixing){ # run apollo_randCoeff and store its names
     namesList$draws <- names(apollo_inputs$draws)
     env <- c(apollo_inputs$database, as.list(apollo_beta), apollo_inputs$draws)
